Forms reference — django-authopenid v1.0 documentation

### Navigation

- index
- previous |
- django-authopenid v1.0 documentation »

# Forms reference

class `django_authopenid.forms.` `OpenidSigninForm`(data=None, files=None, auto_id='id_%s', prefix=None, initial=None, error_class=<class 'django.forms.util.ErrorList'>, label_suffix=':', empty_permitted=False)
  signin form

class `django_authopenid.forms.` `OpenidRegisterForm`(*args, **kwargs)
  openid signin form

class `django_authopenid.forms.` `AssociateOpenID`(user, *args, **kwargs)
  new openid association form

class `django_authopenid.forms.` `OpenidDissociateForm`(data=None, files=None, auto_id='id_%s', prefix=None, initial=None, error_class=<class 'django.forms.util.ErrorList'>, label_suffix=':', empty_permitted=False)
  form used to dissociate an openid.

See also

django-registration forms documentation for more informations

### Navigation

- index
- previous |
- django-authopenid v1.0 documentation »